Rename art-cache to dalvik-cache

Change-Id: I294995066aecc29fbd739c3e9e6f60934f743064
diff --git a/src/heap.cc b/src/heap.cc
index e6d3a81..f39c26e 100644
--- a/src/heap.cc
+++ b/src/heap.cc
@@ -211,10 +211,10 @@
       // If the /system file exists, it should be up-to-date, don't try to generate
       image_space = ImageSpace::Create(image_file_name);
     } else {
       // If the /system file didn't exist, we need to use one from the art-cache.
       // If the cache file exists, try to open, but if it fails, regenerate.
       // If it does not exist, generate.
-      image_file_name = GetArtCacheFilenameOrDie(image_file_name);
+      image_file_name = GetDalvikCacheFilenameOrDie(image_file_name);
       if (OS::FileExists(image_file_name.c_str())) {
         image_space = ImageSpace::Create(image_file_name);
       }
@@ -211,10 +211,10 @@
       image_space = ImageSpace::Create(image_file_name);
     } else {
-      // If the /system file didn't exist, we need to use one from the art-cache.
+      // If the /system file didn't exist, we need to use one from the dalvik-cache.
       // If the cache file exists, try to open, but if it fails, regenerate.
       // If it does not exist, generate.